timeseries.Signal.plot — GDA Toolbox v1.0 Manual

# timeseries.Signal.plot

`Signal.` `plot`(canvas, title='Signal')

  Plot the Signal.

  Parameters: | canvas : class:`bokeh.plotting.figure.Figure` or `matplotlib.axes._subplots.AxesSubplot` A bokeh or pyplot canvas to draw on. Create one with `canvas = bokeh.plotting.figure()` or `fig,canvas = matplotlib.pyplot.subplots()`

  Notes

  You have to save or show axes after running this call.

#### Previous topic

timeseries.Signal.normalize

#### Next topic

timeseries.Signal.profile